==> atmosphere-gwt-auction-0.4-sources.jar: org/gwtcomet/server/StreamingServiceImpl.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.gwtcomet.server;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;
import cometedgwt.auction.client.StreamingServiceInternalGWT;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.atmosphere.util.BroadcasterLookup;
import org.atmosphere.util.BroadcasterLookup.OutOfScopeException;

public class StreamingServiceImpl extends RemoteServiceServlet implements StreamingServiceInternalGWT {

    private final BroadcasterLookup bl = new BroadcasterLookup();

    public StreamingServiceImpl() {
        super();
    }

    public void subscribeToTopic(String queueName) {
        String clientId = getThreadLocalRequest().getSession().getId();
    }

    public void sendMessage(String queueName, String message) {
        try {
            bl.lookup("GWT").broadcast(new StreamingServiceBusiness.Event(queueName, message));
        } catch (OutOfScopeException ex) {
            Logger.getLogger(StreamingServiceImpl.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    public void unsubscribeFromTopic(String queueName) {
        String clientId = getThreadLocalRequest().getSession().getId();
        getServletContext().log("client " + clientId + " unsubscribed from topic " + queueName);
    }
}

==> atmosphere-gwt-auction-0.5.1-sources.jar: org/gwtcomet/server/StreamingServiceImpl.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.gwtcomet.server;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;
import cometedgwt.auction.client.StreamingServiceInternalGWT;
import org.atmosphere.cpr.DefaultBroadcaster;
import org.atmosphere.util.BroadcasterLookup;

public class StreamingServiceImpl extends RemoteServiceServlet implements StreamingServiceInternalGWT {

    public StreamingServiceImpl() {
        super();
    }

    public void subscribeToTopic(String queueName) {
    }

    public void sendMessage(String queueName, String message) {
        BroadcasterLookup.lookup(DefaultBroadcaster.class,"GWT")
                .broadcast(new StreamingServiceBusiness.Event(queueName, message));
    }

    public void unsubscribeFromTopic(String queueName) {
        String clientId = getThreadLocalRequest().getSession().getId();
        getServletContext().log("client " + clientId + " unsubscribed from topic " + queueName);
    }
}
